@@ -16,9 +16,14 @@
 
 mp3_to_wav <- function(file, output_dir = dirname(file), delete = FALSE)
 {
+  mp3 <- tuneR::readMP3(file)
+
+  extensible <- if (slot(mp3, "samp.rate") > 44100) TRUE else FALSE
+
   tuneR::writeWave(
-    object = tuneR::readMP3(file),
-    filename = file.path(output_dir, basename(paste0(tools::file_path_sans_ext(file), ".wav")))
+    object = mp3,
+    file = file.path(output_dir, basename(paste0(tools::file_path_sans_ext(file), ".wav"))),
+    extensible = extensible
   )
 
   if (delete)
@@ -51,4 +56,4 @@ rotate90 <- function(m) t(m)[,NROW(m):1]
 #' @rdname to_dB
 #'
 
-to_dB <- function(x, ref) pmax(20 * log10(x / ref), -120)
+to_dB <- function(x, ref = 1) 20 * log10(x / ref)
