@@ -27,29 +27,27 @@
 #include "bb_extract.h"
 
 // [[Rcpp::export]]
-Rcpp::List threshold_detection_impl(
-    const std::vector<int>& audio_samples,
-    size_t sample_rate,
-    size_t threshold,
-    double min_d,
-    double max_d,
-    double TBE_min,
-    double TBE_max,
-    double EDG,
-    size_t LPF,
-    size_t HPF,
-    double dur_t,
-    double snr_t,
-    double angl_t,
-    size_t FFT_size,
-    double FFT_overlap,
-    double start_t,
-    double end_t,
-    const size_t NWS,
-    double KPE,
-    double KME
-)
+Rcpp::List threshold_detection_impl(const std::vector<int>& audio_samples,
+                              size_t sample_rate,
+                              size_t threshold,
+                              double min_d,
+                              double max_d,
+                              double TBE,
+                              double EDG,
+                              size_t LPF,
+                              size_t HPF,
+                              double dur_t,
+                              double snr_t,
+                              double angl_t,
+                              size_t FFT_size,
+                              double FFT_overlap,
+                              double start_t,
+                              double end_t,
+                              const size_t NWS,
+                              double KPE,
+                              double KME)
 {
+
   std::deque<int> peak_locations;
   std::deque< std::vector<double> > background_noises;
 
@@ -108,10 +106,7 @@ Rcpp::List threshold_detection_impl(
   {
     for (size_t i = 1; i < n_events; i++)
     {
-      if (
-          ((audio_events[i].start - audio_events[i - 1].end) / (double)sample_rate * 1000) < TBE_min ||
-          ((audio_events[i].start - audio_events[i - 1].end) / (double)sample_rate * 1000) > TBE_max
-         )
+      if (((audio_events[i].start - audio_events[i - 1].end) / (double)sample_rate * 1000) < TBE)
       {
         del[i - 1] = true;
         del[i] = true;
